<?php
require 'vendor/autoload.php';
use Firebase\JWT\JWT;
class FirebaseNotification
{
    private $serviceAccountFile = __DIR__ . '/gro777-7a3e0-firebase-adminsdk-n94p9-2239d4cdab.json'; // Ensure the correct path
    private $fcmUrl = 'https://fcm.googleapis.com/v1/projects/gro777-7a3e0/messages:send';
    public function sendNotification($deviceToken, $title, $body, $clickActionUrl)
    {
        if (!$deviceToken) {
            return 'Error: Device token is missing.';
        }
        try {
            // Create the authentication token
            $authToken = $this->createAuthToken();
            // Prepare the notification payload
            $payload = [
                "message" => [
                    "token" => $deviceToken,
                    "notification" => [
                        "title" => $title,
                        "body" => $body,
                    ],
                    "data" => [
                        "click_action" => $clickActionUrl,
                    ]
                ]
            ];
            // Initialize cURL
            $ch = curl_init($this->fcmUrl);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, [
                "Authorization: Bearer $authToken",
                "Content-Type: application/json",
            ]);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload));
            // Execute cURL request
            $response = curl_exec($ch);
            if (curl_errno($ch)) {
                throw new Exception('cURL Error: ' . curl_error($ch));
            }
            // Close cURL
            curl_close($ch);
            // Return the response
            return $response;
        } catch (Exception $e) {
            return 'Error: ' . $e->getMessage();
        }
    }
    private function createAuthToken()
    {
        if (!file_exists($this->serviceAccountFile)) {
            throw new Exception('Firebase service account file not found.');
        }
        $serviceAccountFileContents = file_get_contents($this->serviceAccountFile);
        if ($serviceAccountFileContents === false) {
            throw new Exception('Unable to read Firebase service account file.');
        }
        $serviceAccount = json_decode($serviceAccountFileContents, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new Exception('Invalid JSON in Firebase service account file: ' . json_last_error_msg());
        }
        $privateKey = $serviceAccount['private_key'] ?? null;
        if (!$privateKey) {
            throw new Exception('Private key is missing from the Firebase service account file.');
        }
        $header = [
            'alg' => 'RS256',
            'typ' => 'JWT',
        ];
        $claims = [
            'iss' => $serviceAccount['client_email'], // Issuer
            'sub' => $serviceAccount['client_email'], // Subject
            'aud' => 'https://fcm.googleapis.com/',
            'iat' => time(),
            'exp' => time() + 3600, // Token valid for 1 hour
        ];
        // Generate JWT token
        return JWT::encode($claims, $privateKey, 'RS256', null, $header);
    }
}
?>
